# TelegramBot API

Master: [![Build Status](https://secure.travis-ci.org/arcturial/telegrambot.png?branch=master)](http://travis-ci.org/arcturial/telegrambot)

This library wraps the [TelegramBot API](https://core.telegram.org/bots) and can be used to interact with bots generated by using [BotFather](https://core.telegram.org/bots#botfather)

## Installation

``` nodejs
npm install telegrambot
```

## Available Methods

All methods available on the API can be access using this library. The list of methods and expected results can be found in the [Bot API document](https://core.telegram.org/bots/api).

The methods can be used like this:

``` nodejs
var TelegramBot = require('telegrambot');

var api = new TelegramBot('<YOUR TOKEN HERE>');

api.getMe(callback);

api.sendMessage(opts, callback);

api.forwardMessage(opts, callback);

api.sendPhoto(opts, callback;

api.sendAudio(opts, callback);

api.sendDocument(opts, callback);

api.sendSticker(opts, callback);

api.sendVideo(opts, callback);

api.sendLocation(opts, callback);

api.sendChatAction(opts, callback);

api.getUserProfilePhotos(opts, callback);

api.getUpdates(opts, callback);

api.setWebhook(opts, callback);

```

## Usage

``` nodejs
var TelegramBot = require('telegrambot');
var fs = require('fs');

var api = new TelegramBot('<YOUR TOKEN HERE>');

api.sendMessage({ chat_id: 1, text: 'test' }, function (err, message) {
    if (err) throw err;
    console.log(message);
});

api.sendPhoto({ chat_id: 1, photo: fs.createReadStream(__dirname + '/test.jpg') }, function (err, message) {
    if (err) throw err;
    console.log(message);
});

```

## Using 'invoke'

The library contains an `invoke` call that can be used to call any API method even before it's been implemented as part of the library interface. All library calls wrap this call and serve mostly as a convenience.

``` nodejs
var TelegramBot = require('telegrambot');
var fs = require('fs');

var api = new TelegramBot('<YOUR TOKEN HERE>');

api.invoke('getMe', {}, function (err, me) {
    if (err) throw err;
    console.log(me);
});